const mongoose = require('mongoose');
const fs = require('fs');
const logger = require('./src/logging');
const environment = require('./src/environment');
const index = require('./src/express').express();

fs.readFile('/connect/MONGO_CONNECTION_URL/data', (err, data) => {

    let url, mongo_options;

    if(err){
        url = environment.mongo_connection;
    }else{
        url = data.toString('utf8');
    }

    mongo_options = {
        useNewUrlParser: true,
        useUnifiedTopology: true
    };

    mongoose.connect('mongodb://'+url+'', mongo_options).then(() => {
        logger.info('Connected to MongoDB.');
    });

    mongoose.connection.on('reconnect', function (ref) {
        logger.info('Reconnect to MongoDB.');
    });

    mongoose.connection.on('close', function (ref) {
        logger.error('Connection to MongoDB closed.');
        process.exit(0);
    });

    mongoose.connection.on('error', function (ref) {
        logger.error('MongoDB error.');
    });

    mongoose.connection.on('disconnected', function (ref) {
        logger.error('Connection to MongoDB disconnected.');
        process.exit(0);
    });

});

module.exports = index;
