const mongoose = require('mongoose');
const logger = require('../src/logging');
const Schema = mongoose.Schema;

let model;

let ServiceModelSchema = new Schema({
    name: String,
    version: Number,
    timeout: Number
});

ServiceModelSchema.statics.createService = async (element, version) => {
    let services = new model({
        version: version,
        name: element.name,
        timeout: element.timeout
    });

    let saved = await services.save();

    if(saved){
        logger.info('Service %s created with version %d', element.name, version);
    }
};

ServiceModelSchema.statics.deleteService = async (id) => {
    try {
        await model.deleteOne({_id: id});
    }catch (err) {
        logger.error(err);
    }
};

ServiceModelSchema.statics.removeOldServices = async (version) => {

    let doc_lt, doc_gt = [];

    try {
        doc_lt = await model.find({}).where('version').lt(version).exec();
        doc_gt = await model.find({}).where('version').gt(version).exec();
    }catch (e) {
        logger.error(e);
    }

    for(let element of doc_lt){
        await model.deleteService(element._id);
    }

    for(let element of doc_gt){
        await model.deleteService(element._id);
    }

};

ServiceModelSchema.statics.insertOrUpdateServices = async (services, version) => {
    await Promise.all(services.map(async (element) => {

        let result = await model.exists({name: element.name, version: version});

        if(!result){
            await model.createService(element, version);
        }
    }));
};

model = mongoose.model('services', ServiceModelSchema );
module.exports = model;
