const mongoose = require('mongoose');
const Schema = mongoose.Schema;

let model;

let WorkerModelSchema = new Schema({
    ip: String,
    port: String,
    last: Number,
    service: String,
    active: { type: Boolean, default: false},
    activeJob: {type: Schema.Types.ObjectId, ref: 'jobs'},
});

WorkerModelSchema.statics.removeWorker =  async (id) => {
    await model.deleteOne({_id: id});
};

WorkerModelSchema.statics.createWorker =  async (name, ip, port, cb) => {
    let worker = new model({
        ip: ip,
        port: port,
        last: Date.now(),
        service: name
    });

    let saved = await worker.save();

    if(saved){
        cb();
    }
}

WorkerModelSchema.statics.updateWorkerTime = async (id, cb) => {
    let doc2 = await model.findOne({_id: id});

    if(doc2){
        doc2.last = Date.now();

        let saved = await doc2.save();

        if(saved){
            cb();
        }
    }

};

WorkerModelSchema.statics.removeOldWorker =  async () => {
    let last = Date.now();
    await model.deleteMany({}).where('last').lt(last - 20000).exec();
};

WorkerModelSchema.statics.insertOrUpdateWorker = async (name, ip, port, callback_created, callback_updated) => {
    let docc2 = await model.findOne({'service': name, 'ip': ip, 'port': port}).exec();

    if(docc2){
        await model.updateWorkerTime(docc2._id, callback_updated);
    }else{
        await model.createWorker(name, ip, port, callback_created);
    }
};
model = mongoose.model('worker', WorkerModelSchema );
module.exports = model;
