const express = require('express');
const router = express.Router();
const serviceModel = require('../models/services');
const jobModel = require('../models/jobs');

router.post('/create', async (req, res) => {

	await jobModel.removeOldJobs();

	let service_doc = await serviceModel.findOne({name: req.body.service});

	if(service_doc){

        let job = new jobModel({
            service: service_doc.name,
            param: req.body.param,
            state: 'open'
        });

        let doc = await job.save();

        await jobModel.process();

        res.send({
            state: 'ok',
            id: doc.id
        });

    }else{
        res.send({
            state: 'error',
            message: 'service not known'
        });
    }
});

router.post('/success', async (req, res) => {

	jobModel.success(req.body.id, req.body.result, () => {
		jobModel.process();
	});

    res.json({
        message: 'ok'
    });

});

router.put('/update', async (req, res) => {

    await jobModel.update(req.body.id, req.body.result, jobModel.process);

    res.json({
        message: 'ok'
    });
});

router.get('/:id', async (req, res) => {
    try {
        let job_doc = await jobModel.findById({_id: req.params.id});

        await jobModel.getQueuePosition(job_doc._id, (count) => {
            res.send({
                message: 'ok',
                state: job_doc.state,
                name: job_doc.service,
                queue_position: count,
                result: job_doc.result
            });
        });

    }catch (e) {
        res.status(404).send({
            message: 'error'
        });
    }
});


module.exports = router;
