let express = require('express'),
	logger = require('morgan'),
	logger2 = require('./logging'),
    bodyParser = require('body-parser');

exports.express = () => {

	let app = express();

    /**
     * Routes
     */
    let registerRouter = require('../routes/register');
    let jobsRouter = require('../routes/jobs');

    // Tell the bodyparser middleware to accept more data
    app.use(bodyParser.json({limit: '50mb'}));
    app.use(bodyParser.urlencoded({limit: '50mb', extended: true}));

	app.use(logger('combined'));

	app.use(express.json());
	app.use(express.urlencoded({ extended: false }));

	app.use('/register', registerRouter);
	app.use('/jobs', jobsRouter);

	app.use('/get_container_status', (req, res, next) => {
		res.state = 200;
		res.send('ok');
	});

    // catch 404 and forward to error handler
    app.use(function(req, res, next) {
        next();
    });

    // error handler
    app.use(function(err, req, res, next) {
        // set locals, only providing error in development
        res.locals.message = err.message;
        res.locals.error = req.app.get('env') === 'development' ? err : {};

        // render the error page
        res.status(err.status || 500);

        if(req.app.get('env') === 'production'){
            logger2.error(err);
            res.render('error');
        }else{
            res.render('error-dev');
        }

    });

	return app;
};

